import numpy as np
from src.misc import samplerotations_eq3D

def input():
    # Project title
    title = 'simsample_2x2x2'
    # title = 'simsample_20x20x20'

    ## Define diffraction-related parameters:
    # X-ray energy in keV
    Ex = 15.2 # 0.0815 nm
    # desired angular resolution in rad
    dchi = 2*np.pi/120 
    # q values
    q = np.linspace( 10, 35, num=50 )
    # Path to crystal cif file
    cifPath = 'crystals/BaCO3.cif'
    # crystal size (number of unit cells along each axis)
    crystalsize = (15,15,15)
    # crystal symmetry
    symmetry = '222'
    ### Save/load to/from pickle
    diff_pickle = 'diff_baco3_cr151515_q50_chi120'
    diff_load = True # if true, above parameters will be ignored
    
    ## Define tomography-related parameters:    
    # beam size in um (FWHM)
    Dbeam = 0.3
    # step size for scanning
    Dstep = 0.5
    # field of view - number of scanning points in y and z
    # fov = (4,4) # for '2x2x2' sample with 1 padding
    fov = (40,40) # for '20x20x20' sample with 10 padding
    # voxelmask
    voxelmask = 'data/voxelmask_%s.txt' % title
    # define rotation and tilt angles
    d_omega = 10 # stepsize of rotation angles at zero tilt in degree
    kappa = (0,15,30,45) # tilt angles in degree
    Ome, Kap = samplerotations_eq3D( d_omega, kappa )
    shifts = {
        'phi': Ome, # rotation angles
        'kap': Kap, # tilt angles
        'shifty': np.zeros_like(Ome), # shifts resulting from alignment
        'shiftz': np.zeros_like(Ome), # shifts resulting from alignment
        'tomogram': np.ones([fov[0],fov[0],fov[1]], np.float64)
    }
    ### Save/load to/from pickle
    tomo_pickle = 'tomo_%s' % title
    tomo_load = True # if true, above parameters will be ignored

    return title, \
        Ex, q, dchi, cifPath, crystalsize, symmetry,\
        Dbeam, Dstep, fov, voxelmask,\
        shifts, \
        diff_pickle, diff_load, tomo_pickle, tomo_load