import numpy as np
from src.misc import samplerotations_eq3D

def input():
    # Project title
    title = 'helix_s7_q50_phi120' 

    ## Define diffraction-related parameters:
    # x-ray energy in keV
    Ex = 15.2 # 0.0815 nm
    # angular resolution on detector
    dchi = 2*np.pi / 30
    # q range for fitting
    # q = np.linspace( 1.209, 3.471, num=50 )
    q = np.linspace( 10, 35, num=10 )
    # path to crystal cif file
    cifPath = 'crystals/BaCO3.cif'
    # crystal size (repeat unit cell along each axis)
    crystalsize = (5,5,5)
    # crystal symmetry
    symmetry = '222'
    ### Save/load to/from pickle
    diff_pickle = 'diff_baco3_template'
    diff_load = True # if true, above parameters will be ignored

    ## Define tomography-related parameters:
    # beam size in um (FWHM)
    Dbeam = 0.3    
    # step size for scanning
    Dstep = 0.5
    # field of view (ny,nz)
    fov = (140,180)
    # voxelmask (alternative, put None to define on the run)
    voxelmask = 'input/voxelmask_s7_sastt.txt'
    # shifts file from SASTT alignment
    shifts = '/dataSATA/data_synchrotron/esrf_id13_2023_09_ihmi1513_biomorphs/ihmi1531/id13/20230914/SCRIPTS/matlab/analysis/SASTT/helix_s7_20230921/raw_data/SASTT_helix_s7_20230921_aligned_FBP.mat'
    # or create shifts dictionary
    omega, kappa = samplerotations_eq3D( 60, (0,15)) # (rotation stepsize at kappa 0, (list of tilt angles))
    shifts = {
        'phi': omega,
        'kap': kappa,
        'shifty': np.zeros_like(omega),
        'shiftz': np.zeros_like(omega),
        'tomogram': np.ones([fov[0],fov[0],fov[1]], np.float64)
    }
    ### Save/load to/from pickle
    tomo_pickle = 'tomo_helix_s7'
    tomo_load = True # if true, above parameters will be ignored (except if nVox is used below)

    # path to integrated data from pyFAI
    datapath = '/dataSSD/moritz/data/helix_s7_q50_phi120'
    # Save/load to/from pickle
    data_pickle = 'data_helix_s7_q50_phi60_single'
    data_load = True # if true, above parameters will be ignored (except if nVox is used below)

    return title, \
        Ex, q, dchi, cifPath, crystalsize, symmetry,\
        Dbeam, Dstep, fov, voxelmask,\
        shifts, datapath,\
        diff_pickle, diff_load, tomo_pickle, tomo_load, \
        data_pickle, data_load
