function [symm] = collect_symm(gc,gs,n_max,precision)
% collect_symm find sets of coefficients up to n_max that make the
% hyperspherical harmonic expansion invariant to the cubic crystal point
% group generators. These can  be interpreted as defining a compact basis
% for an orientation distribution obeying the required symmetry, namely,
% the symmetrized hyperspherical harmonics.
% 
% Inputs:
%   n_max - maximum value of N for which sets of coefficients are found.
% 
% Outputs:
%   symm  - a cell array containing three columns which are the outputs X,
%           L and M of the make_symm_pq function. The value of N starts at
%           zero and increases with the row.
% 
% Copyright 2023 Jeremy Mason
% 
% Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
% http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
% http://opensource.org/licenses/MIT>, at your option. This file may not be
% copied, modified, or distributed except according to those terms.
    symm = cell(n_max + 1, 3);

    n = 2;
    while n <= n_max
        [X, L, M] = make_symm(gc,gs,n, precision);%1.e-12
        if ~isempty(X)
            symm{n + 1, 1} = X;
            symm{n + 1, 2} = L;
            symm{n + 1, 3} = M;
        end

        n = n + 2;
    end
end