import numpy as np
import matplotlib.pyplot as plt
import matplotlib.colors as colors

""" Library for creating masks """

def mask_q_fit( q, powder_exp, powder_sim, title='' ):
    """ Creates a figure where the user can draw which q-regions
    they want to use for optimization
    
    Parameters
    ----------
    q : 1D ndarray, float
        original q-values
    powder_exp, powder_sim : 1D ndarray, float
        experimental and simulated powder diffraction patterns

    returns: 
    ------------
    mask : 1D ndarray, bool
    """
    powder_sim = powder_sim * powder_exp.max()/powder_sim.max()
    mask = np.zeros_like(powder_sim).astype(bool)

    def replot( mask ):
        ax.clear() 
        ax.plot( q, powder_sim, label='model' )
        ax.plot( q, powder_exp, label='data' )
        ax.plot( q[mask], powder_sim[mask], 'go', label='mask')
        ax.set_title(title+'\nClick and hold. LMB select, RMB unselect')
        ax.legend()

    fig, ax = plt.subplots( figsize = (10,10))
    replot( mask )

    def on_click(event):    
        global start_point
        if event.inaxes != ax:
            return
        start_point = np.searchsorted( q, event.xdata )

    def on_release(event):
        global start_point
        if event.inaxes != ax or start_point is None:
            return
        
        end_point = np.searchsorted( q, event.xdata, side='right' )
        if end_point<start_point:
            tmp = start_point.copy()
            start_point = end_point.copy()
            end_point = tmp

        if event.button == 1:  # Left mouse button: mask
            mask[ start_point:end_point ] = 1

        elif event.button == 3:  # Right mouse button: unmask
            mask[ start_point:end_point ] = 0

        replot( mask ) 
        fig.canvas.draw_idle()

    cid_click = fig.canvas.mpl_connect('button_press_event', on_click)
    cid_release = fig.canvas.mpl_connect('button_release_event', on_release)
    plt.show()
    return mask